@@ -5,7 +5,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2019	PgPool Global Development Group
+ * Copyright (c) 2003-2015	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -329,12 +329,7 @@ void pool_connection_pool_timer(POOL_CONNECTION_POOL *backend)
 		(errmsg("setting backend connection close timer"),
 			 errdetail("close time %ld", time(NULL))));
 
-	/* Set connection close time */
-	for (i = 0; i < NUM_BACKENDS; i++)
-	{
-		if (CONNECTION_SLOT(backend, i))
-			CONNECTION_SLOT(backend, i)->closetime = time(NULL);
-	}
+	MASTER_CONNECTION(backend)->closetime = time(NULL);		/* set connection close time */
 
 	if (pool_config->connection_life_time == 0)
 		return;
@@ -384,7 +379,7 @@ void pool_backend_timer(void)
 	now = time(NULL);
 
 	ereport(DEBUG1,
-			(errmsg("backend timer handler called at %ld", now)));
+		(errmsg("backend timer handler called at%ld", now)));
 
 	for (i=0;i<pool_config->max_pool;i++, p++)
 	{
@@ -565,7 +560,7 @@ static bool connect_with_timeout(int fd, struct addrinfo *walk, char *host, int
 			return false;
 		}
 
-		if (health_check_timer_expired && getpid() == mypid)		/* has health check timer expired */
+		if (health_check_timer_expired)		/* has health check timer expired */
 		{
 			ereport(LOG,
 				(errmsg("failed to connect to PostgreSQL server on \"%s:%d\" using INET socket",host,port),
@@ -699,9 +694,18 @@ static bool connect_with_timeout(int fd, struct addrinfo *walk, char *host, int
 					continue;
 				}
 
-				ereport(LOG,
-					(errmsg("failed to connect to PostgreSQL server on \"%s:%d\" using INET socket",host,port),
-						 errdetail("select() system call failed with an error \"%s\"",strerror(errno))));
+				else if (health_check_timer_expired && errno == EINTR)
+				{
+					ereport(LOG,
+							(errmsg("failed to connect to PostgreSQL server on \"%s:%d\" using INET socket",host,port),
+							 errdetail("health check timer expired")));
+				}
+				else
+				{
+					ereport(LOG,
+							(errmsg("failed to connect to PostgreSQL server on \"%s:%d\" using INET socket",host,port),
+							 errdetail("select() system call failed with an error \"%s\"",strerror(errno))));
+				}
 				close(fd);
 				return false;
 			}
@@ -823,7 +827,6 @@ static POOL_CONNECTION_POOL *new_connection(POOL_CONNECTION_POOL *p)
 	POOL_CONNECTION_POOL_SLOT *s;
 	int active_backend_count = 0;
 	int i;
-	bool		status_changed = false;
 
     MemoryContext oldContext = MemoryContextSwitchTo(TopMemoryContext);
     
@@ -855,9 +858,6 @@ static POOL_CONNECTION_POOL *new_connection(POOL_CONNECTION_POOL *p)
 					(errmsg("creating new connection to backend"),
 					errdetail("skipping backend slot %d because global backend_status = %d",
 						   i, BACKEND_INFO(i).backend_status)));
-
-			/* sync local status with global status */
-			*(my_backend_status[i]) = BACKEND_INFO(i).backend_status;
 			continue;
 		}
 
@@ -870,7 +870,7 @@ static POOL_CONNECTION_POOL *new_connection(POOL_CONNECTION_POOL *p)
 			 */
 			if (pool_config->fail_over_on_backend_error)
 			{
-				notice_backend_error(i, true);
+				notice_backend_error(i, REQ_DETAIL_SWITCHOVER);
 				ereport(FATAL,
 					(errmsg("failed to create a backend connection"),
 						 errdetail("executing failover on backend")));
@@ -881,7 +881,7 @@ static POOL_CONNECTION_POOL *new_connection(POOL_CONNECTION_POOL *p)
 				 * If we are in streaming replication mode and the node is a
 				 * standby node, then we skip this node to avoid fail over.
 				 */
-				if (STREAM && !IS_PRIMARY_NODE_ID(i))
+				if (SL_MODE && !IS_PRIMARY_NODE_ID(i))
 				{
 					ereport(LOG,
 							(errmsg("failed to create a backend %d connection", i),
@@ -890,7 +890,7 @@ static POOL_CONNECTION_POOL *new_connection(POOL_CONNECTION_POOL *p)
 					/* set down status to local status area */
 					*(my_backend_status[i]) = CON_DOWN;
 
-					/* if master_node_id is not updated, then update it */
+					/* if master_node_id is not updated, the update it */
 					if (Req_info->master_node_id == i)
 					{
 						int old_master = Req_info->master_node_id;
@@ -922,16 +922,11 @@ static POOL_CONNECTION_POOL *new_connection(POOL_CONNECTION_POOL *p)
 
 		pool_init_params(&s->con->params);
 	
-		if (BACKEND_INFO(i).backend_status != CON_UP)
-		{
-			BACKEND_INFO(i).backend_status = CON_UP;
-			status_changed = true;
-		}
+		BACKEND_INFO(i).backend_status = CON_UP;
 		active_backend_count++;
 	}
 
-	if (status_changed)
-		(void)write_status_file();
+	(void)write_status_file();
 
     MemoryContextSwitchTo(oldContext);
 
