@@ -1679,7 +1679,8 @@ static void pool_reset_memqcache_buffer(void)
 		 * if the query context is still under use, we cannot discard
 		 * temporary cache.
 		 */
-		if (can_query_context_destroy(session_context->query_context))
+		if ((SL_MODE && pool_is_doing_extended_query_message()) ||
+			can_query_context_destroy(session_context->query_context))
 		{
 			ereport(DEBUG1,
 				(errmsg("memcache reset buffer"),
@@ -3362,6 +3363,7 @@ void pool_handle_query_cache(POOL_CONNECTION_POOL *backend, char *query, Node *n
 					 * if DML/DDL modifies the TABLE which SELECT uses.
 					 */
 					pool_check_and_discard_cache_buffer(num_oids, oids);
+					pool_reset_memqcache_buffer();
 				} 
 			}
 			else if (num_oids == 0)
