@@ -3,7 +3,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2019	PgPool Global Development Group
+ * Copyright (c) 2003-2018	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -210,14 +210,7 @@ int pattern_compare(char *str, const int type, const char *param_name)
 	}
 
 	s = strip_quote(str);
-	if (!s)
-	{
-		elog(WARNING, "pattern_compare: strip_quote() returns error");
-		return -1;
-	}
-
-	for (i = 0; i < *pattc; i++)
-	{
+	for (i = 0; i < *pattc; i++) {
 		if (lists_patterns[i].type != type)
 			continue;
 
@@ -259,31 +252,12 @@ int pattern_compare(char *str, const int type, const char *param_name)
 	return result;
 }
 
-/*
- * Returns double quotes stripped version of malloced string.
- * Callers must free() after using it.
- * Returns NULL on error.
- */
-static char *
-strip_quote(char *str)
+static char *strip_quote(char *str)
 {
-	char	   *after;
-	int		   len;
-	int			i = 0;
+	char *after;
+	int i = 0;
 
-	len = strlen(str);
-	after = malloc(sizeof(char) * len + 1);
-	if (!after)
-	{
-		return NULL;
-	}
-
-	if (len == 0)
-	{
-		/* empty string case */
-		*after = '\0';
-		return after;
-	}
+	after = malloc(sizeof(char) * strlen(str) + 1);
 
 	do {
 		if (*str != '"')
@@ -332,9 +306,7 @@ static bool function_call_walker(Node *node, void *context)
 
 			if (ctx->pg_terminate_backend_pid == 0 && strcmp("pg_terminate_backend", fname) == 0)
 			{
-				/* PostgreSQL 14 or after accept two arguments. */
-				if (list_length(fcall->args) == 1 ||
-					list_length(fcall->args) == 2)
+				if (list_length(fcall->args) == 1)
 				{
 					Node *arg = linitial(fcall->args);
 					if (IsA(arg, A_Const) &&
@@ -618,7 +590,7 @@ static bool is_temp_table(char *table_name)
  * regclass (or its variant) here, because temporary tables never have
  * schema qualified name.
  */
-#define ISTEMPQUERY83 "SELECT count(*) FROM pg_catalog.pg_class AS c, pg_namespace AS n WHERE c.relname = '%s' AND c.relnamespace = n.oid AND n.nspname ~ '^pg_temp_'"
+#define ISTEMPQUERY83 "SELECT count(*) FROM pg_class AS c, pg_namespace AS n WHERE c.relname = '%s' AND c.relnamespace = n.oid AND n.nspname ~ '^pg_temp_'"
 
 /*
  * Query to know if the target table is a temporary one.  This query
@@ -1202,12 +1174,6 @@ select_table_walker(Node *node, void *context)
 		}
 	}
 
-	/* Skip Data-Modifying Statements in SELECT. */
-	else if (IsA(node, InsertStmt) || IsA(node, DeleteStmt) || IsA(node, UpdateStmt))
-	{
-		return false;
-	}
-
 	return raw_expression_tree_walker(node, select_table_walker, context);
 }
 
